@@ -1,25 +1,14 @@
-from __future__ import absolute_import, unicode_literals
-
 import logging
 
 import pykka
+from pykka.messages import ProxyCall
 
 logger = logging.getLogger(__name__)
 
 
-def send_async(cls, event, **kwargs):
-    # This file is imported by mopidy.backends, which again is imported by all
-    # backend extensions. By importing modules that are not easily installable
-    # close to their use, we make some extensions able to run their tests in a
-    # virtualenv with global site-packages disabled.
-    import gobject
-
-    gobject.idle_add(lambda: send(cls, event, **kwargs))
-
-
 def send(cls, event, **kwargs):
     listeners = pykka.ActorRegistry.get_by_class(cls)
-    logger.debug('Sending %s to %s: %s', event, cls.__name__, kwargs)
+    logger.debug("Sending %s to %s: %s", event, cls.__name__, kwargs)
     for listener in listeners:
         # Save time by calling methods on Pykka actor without creating a
         # throwaway actor proxy.
@@ -30,16 +19,16 @@ def send(cls, event, **kwargs):
         # to react and return their exceptions to us. Since emitting events in
         # practise is making calls upwards in the stack, blocking here would
         # quickly deadlock.
-        listener.tell({
-            'command': 'pykka_call',
-            'attr_path': ('on_event',),
-            'args': (event,),
-            'kwargs': kwargs,
-        })
+        listener.tell(
+            ProxyCall(
+                attr_path=["on_event"],
+                args=[event],
+                kwargs=kwargs,
+            )
+        )
 
 
-class Listener(object):
-
+class Listener:
     def on_event(self, event, **kwargs):
         """
         Called on all events.
@@ -55,4 +44,6 @@ class Listener(object):
             getattr(self, event)(**kwargs)
         except Exception:
             # Ensure we don't crash the actor due to "bad" events.
-            logger.exception('Triggering event failed: %s', event)
+            logger.exception(
+                "Triggering event failed: %s(%s)", event, ", ".join(kwargs)
+            )
